<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<HEAD>
  <TITLE>DRBL FAQ/Q&A</TITLE>
  <style type="text/css">
<!--
.style1 {color: #D6D3CE}
-->
  </style>
</HEAD>
<STYLE>
A {text-decoration: none}
</STYLE>
<BODY>
<CENTER>
<IMG SRC="../img/drbl_small.jpg" border="0" ALT="DRBL logo"></IMG>
<font color="#d220ff" size=+2><b><a name=\"top">DRBL FAQ/Q&A</a></b></font>
<IMG SRC="../img/drbl_small.jpg" border="0" ALT="DRBL logo"></IMG>
<span class="style1"></span><a name="1_Common"></a><table border=0 width="98%"><tr><td bgcolor="#0066ff"><p/><font size=+1 color="#FFffff">  Common</font><br></td></tr><tr><td bgcolor="ffccff"><font size=-1>Type: General FAQ
</font></td></tr><tr><td bgcolor="#ffffff"><dl><li type="square"><a href="fine-print.php?path=./1_Common/00_what_is_nchc.faq#00_what_is_nchc.faq">What is NCHC ?
</a><li type="square"><a href="fine-print.php?path=./1_Common/01_DRBL_LTSP.faq#01_DRBL_LTSP.faq">What are the differences between DRBL and LTSP ?
</a><li type="square"><a href="fine-print.php?path=./1_Common/02_hardware_requirement.faq#02_hardware_requirement.faq">What kind of server and client should I buy if I want to use DRBL ?
</a><li type="square"><a href="fine-print.php?path=./1_Common/03_source_code.faq#03_source_code.faq">Where can I download the source codes ?
</a></dl></td><tr><br></table><a name="2_System"></a><table border=0 width="98%"><tr><td bgcolor="#0066ff"><p/><font size=+1 color="#FFffff">  System</font><br></td></tr><tr><td bgcolor="ffccff"><font size=-1>Type: About DRBL system
</font></td></tr><tr><td bgcolor="#ffffff"><dl><li type="square"><a href="fine-print.php?path=./2_System/01_client_files.faq#01_client_files.faq">Where is the corresponding DRBL client directory in the server ?
</a><li type="square"><a href="fine-print.php?path=./2_System/03_append_bootparam_for_client.faq#03_append_bootparam_for_client.faq">How can I append the Linux kernel boot time parameters to the DRBL clients ?
</a><li type="square"><a href="fine-print.php?path=./2_System/04_how_to_debug_in_pxeinitrd.faq#04_how_to_debug_in_pxeinitrd.faq">How can I debug in the PXE initrd when clients boot ?
</a><li type="square"><a href="fine-print.php?path=./2_System/06_client_service.faq#06_client_service.faq">How can I start a DRBL client service (e.g. cron, sysklogd, klogd...) in the server ?
</a><li type="square"><a href="fine-print.php?path=./2_System/07_vmplayer_in_client.faq#07_vmplayer_in_client.faq">How can I run vmplayer in the DRBL client machine ?
</a><li type="square"><a href="fine-print.php?path=./2_System/08_postrun_after_ocs.faq#08_postrun_after_ocs.faq">Is it possible to run a script on the client after Clonezilla finishes cloning ?
</a><li type="square"><a href="fine-print.php?path=./2_System/09_ubuntu_reboot_hang.faq#09_ubuntu_reboot_hang.faq">When I reboot the DRBL client in Ubuntu Breezy Linux, it hangs, What should I do ?
</a><li type="square"><a href="fine-print.php?path=./2_System/10_custom_kernel_for_client.faq#10_custom_kernel_for_client.faq">How can I put my own kernel for DRBL clients ?
</a><li type="square"><a href="fine-print.php?path=./2_System/11_nvidia_ati_module_for_client.faq#11_nvidia_ati_module_for_client.faq">How can I create module for some hardware, like Nvidia, ATI VGA card, to use in client ?
</a><li type="square"><a href="fine-print.php?path=./2_System/12_share_cups_printer.faq#12_share_cups_printer.faq">How can I share the printer in the server to clients ?
</a><li type="square"><a href="fine-print.php?path=./2_System/13_fdos_bios_flash.faq#13_fdos_bios_flash.faq">How can I insert bios flash program and firmware to the freedos so that I can upgrade the BIOS in client ?
</a><li type="square"><a href="fine-print.php?path=./2_System/14_CJK_IME_in_English_env.faq#14_CJK_IME_in_English_env.faq">How to get Japanese (Chinene, Korean) input method in English environment ?
</a><li type="square"><a href="fine-print.php?path=./2_System/15_no_mounted_NFS_in_KDE.faq#15_no_mounted_NFS_in_KDE.faq">How can I hide the mounted NFS icons in my KDE desktop environment ?
</a><li type="square"><a href="fine-print.php?path=./2_System/16_modes_in_DRBL_clonezilla.faq#16_modes_in_DRBL_clonezilla.faq">What the differences between Full DRBL,	Full Clonezilla, DRBL SSI and Clonezilla Box modes ?
</a><li type="square"><a href="fine-print.php?path=./2_System/17_common_share_dir.faq#17_common_share_dir.faq">How can I make a common directory where clients on any box can read, copy and delete files freely ?
</a><li type="square"><a href="fine-print.php?path=./2_System/18_mirror_apt.faq#18_mirror_apt.faq">How can I make a local apt mirror in my Debian or Ubuntu DRBL server and use that as an apt repository ?
</a><li type="square"><a href="fine-print.php?path=./2_System/19_how_to_upgrade_drbl.faq#19_how_to_upgrade_drbl.faq">How can I upgrade DRBL and related packages ?
</a><li type="square"><a href="fine-print.php?path=./2_System/20_no_NFS_dev_icons_in_KDE.faq#20_no_NFS_dev_icons_in_KDE.faq">How can I hide the mounted NFS share icons in KDE desktop ?
</a><li type="square"><a href="fine-print.php?path=./2_System/21_how_to_debug_clonezilla.faq#21_how_to_debug_clonezilla.faq">How can I debug the clonezilla if it fails ?
</a><li type="square"><a href="fine-print.php?path=./2_System/22_RPL_to_PXE.faq#22_RPL_to_PXE.faq">I have some clients which mainboard include NIC, the mainboard supports RPL. How to make the clients to support PXE? 
</a><li type="square"><a href="fine-print.php?path=./2_System/23_Missing_OS.faq#23_Missing_OS.faq">When I use clonezilla to clone MS windows, there is no any problem when saving an image from template machine. However, after the image is restored to another machine, it fails to boot, the error message is "Missing Operating System" or just a blinking underscore. What's going on ?
</a><li type="square"><a href="fine-print.php?path=./2_System/24_How_to_calibrate_client_time.faq#24_How_to_calibrate_client_time.faq">How can I calibrate the clock of clients ?
</a><li type="square"><a href="fine-print.php?path=./2_System/25_tftp_warning_messages.faq#25_tftp_warning_messages.faq">A message "tftp: client does not accept options" appears in syslog file in server , shall I do someting ?
</a><li type="square"><a href="fine-print.php?path=./2_System/26_resize.faq#26_resize.faq">How can I restore the image from small harddisk to larger one ?
</a><li type="square"><a href="fine-print.php?path=./2_System/27_clonezilla_g4l_g4u.faq#27_clonezilla_g4l_g4u.faq">What's the difference between clonezilla and G4L or G4U ?
</a><li type="square"><a href="fine-print.php?path=./2_System/28_change_opensuse_yum_conf.faq#28_change_opensuse_yum_conf.faq">How can I change the yum repository in OpenSuSE/SuSe before I run drblsrv ?
</a><li type="square"><a href="fine-print.php?path=./2_System/29_install_client_kernel.faq#29_install_client_kernel.faq">How can I assign the kernel to let client use that ?
</a><li type="square"><a href="fine-print.php?path=./2_System/29_rpl_with_drbl.faq#29_rpl_with_drbl.faq">If my client computer only supports RPL instead of PXE, can it work with DRBL ?
</a><li type="square"><a href="fine-print.php?path=./2_System/30_SL_drblsrv_offline.faq#30_SL_drblsrv_offline.faq">I am sure that the GNU/Linux I have is compatible with the GNU/Linux distribution which DRBL supports, how can I install drbl on that ?
</a><li type="square"><a href="fine-print.php?path=./2_System/31_prerun_postrun_not_working.faq#31_prerun_postrun_not_working.faq">I put a script file like "myscript.sh" in /opt/drbl/share/ocs/prerun or /opt/drbl/share/ocs/postrun, and I check the option "-o0/--run-prerun-dir", or "-o1/--run-postrun-dir", but mscript.sh is not run. Why ?
</a><li type="square"><a href="fine-print.php?path=./2_System/32_add_package_in_clonezilla_live.faq#32_add_package_in_clonezilla_live.faq">How can I add a package, say ncpfs, in Clonezilla live ?
</a><li type="square"><a href="fine-print.php?path=./2_System/33_how_to_create_custom_clonezilla.faq#33_how_to_create_custom_clonezilla.faq">How can I create my own custom script to run in clonezilla live ?
</a><li type="square"><a href="fine-print.php?path=./2_System/34_2_or_more_casper.faq#34_2_or_more_casper.faq">What if I have 2 or more casper files (filesystem.squashfs) in my system, how can I assign clonezilla live to boot ?
</a><li type="square"><a href="fine-print.php?path=./2_System/35_compile_module_in_client.faq#35_compile_module_in_client.faq">How can I compile a kernel module in the DRBL client so that I can use it for DRBL clients ?
</a><li type="square"><a href="fine-print.php?path=./2_System/36_mirror_drbl.faq#36_mirror_drbl.faq">How can I mirror drbl packages ?
</a><li type="square"><a href="fine-print.php?path=./2_System/37_coexist_with_existing_dhcp.faq#37_coexist_with_existing_dhcp.faq">There is an existing DHCP service in my environment, so it's impossible for me to use the dhcp service comes with DRBL server. Any solution ?
</a><li type="square"><a href="fine-print.php?path=./2_System/38_error_when_saving_ext2_3.faq#38_error_when_saving_ext2_3.faq">I have a weird problem when restoring an image. I always got an error message "Can't read the following volume file: ... /stdin.001".
</a><li type="square"><a href="fine-print.php?path=./2_System/39_remaster_clonezilla_iso.faq#39_remaster_clonezilla_iso.faq">How can I remaster Clonezilla iso file ?
</a><li type="square"><a href="fine-print.php?path=./2_System/40_netinstall_with_kickstart.faq#40_netinstall_with_kickstart.faq">How can I put the kickstart file for netinstall GNU/Linux ?
</a><li type="square"><a href="fine-print.php?path=./2_System/41_freebsd_netinstall.faq#41_freebsd_netinstall.faq">How can I configure FreeBSD network installation in DRBL server ?
</a><li type="square"><a href="fine-print.php?path=./2_System/42_manually_ntfsclone.faq#42_manually_ntfsclone.faq">How can I restore those *.ntfs-img.* images into a partition manually ?
</a><li type="square"><a href="fine-print.php?path=./2_System/43_read_ntfsimg_content.faq#43_read_ntfsimg_content.faq">Is that possible I can read the content of a NTFS image created by Clonezilla ?
</a><li type="square"><a href="fine-print.php?path=./2_System/44_write_to_RW_CD_DVD_in_Clonezilla.faq#44_write_to_RW_CD_DVD_in_Clonezilla.faq">Is there any way I can save image to CD-RW or DVD-RW directly ?
</a><li type="square"><a href="fine-print.php?path=./2_System/45_clonezilla_in_harddrive.faq#45_clonezilla_in_harddrive.faq">Is that possible I can put clonezilla live in my harddrive which already has an OS installed ?
</a><li type="square"><a href="fine-print.php?path=./2_System/46_create_clonezilla_live_from_scratch.faq#46_create_clonezilla_live_from_scratch.faq">How to create Clonezilla live from scratch ?
</a><li type="square"><a href="fine-print.php?path=./2_System/46_multicast_not_working.faq#46_multicast_not_working.faq">When I use Clonezilla server edition to do a multicast clone, the client machines just stay in "Please Wait...", any hint ?
</a><li type="square"><a href="fine-print.php?path=./2_System/47_translation.faq#47_translation.faq">I'd like to translate Clonezilla to other language, how can I help ? 
</a><li type="square"><a href="fine-print.php?path=./2_System/48_drbl_client_active_directory.faq#48_drbl_client_active_directory.faq">How can I config my DRBL clients to use Active Directory authentication ?
</a></dl></td><tr><br></table><hr><small>Last modified: Mon Oct 13 15:06:45 CST 2008</small><p><center><small>
<a href="http://free.nchc.org.tw">NCHC Free Software Lab</a>. All Rights Reserved.
Anyone is permitted to copy and distribute verbatim copies of this document under the terms of the <a href="http://www.gnu.org/licenses/fdl.html">GNU FDL</a> Free Documentation License.
</center></small>
</CENTER>
<hr>
<script type="text/javascript"><!--
google_ad_client = "pub-9507710613356481";
google_ad_width = 728;
google_ad_height = 90;
google_ad_format = "728x90_as";
google_ad_type = "text_image";
google_ad_channel ="";
//--></script>
<script type="text/javascript"
  src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
</script>
<p>
<script type="text/javascript"><!--
google_ad_client = "pub-9507710613356481";
google_ad_width = 728;
google_ad_height = 90;
google_ad_format = "728x90_as";
google_ad_type = "image";
google_ad_channel = "";
//--> </script>
<script type="text/javascript"
  src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
</script>
<p>
<script type="text/javascript"><!--
google_ad_client = "pub-9507710613356481";
google_ad_width = 728;
google_ad_height = 15;
google_ad_format = "728x15_0ads_al_s";
google_ad_channel = "";
//-->
</script>
<script type="text/javascript"
  src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
</script>
</BODY>
</HTML>
